import{C as s}from"./AnimatedDannie.9bc4e7e2.js";import{C as p}from"./Card.7e975fe9.js";import{_ as m,G as _}from"./Header.a599b1db.js";import"./translations.d159963e.js";import{_ as l}from"./_plugin-vue_export-helper.eefbdd86.js";import{_ as u}from"./default-i18n.20001971.js";import{c as d,C as o,m as t,x as n,o as f,a as g}from"./runtime-dom.esm-bundler.647fa2bb.js";import"./index.44a18132.js";import"./helpers.a876ae70.js";import"./Tooltip.e09c91a9.js";import"./Caret.c1ae0fd1.js";import"./index.6b623118.js";import"./Slide.44995a8e.js";import"./vue-router.f667265d.js";import"./addons.95e96e7e.js";import"./upperFirst.a182d36c.js";import"./_stringToArray.f9ddb970.js";import"./toString.98bc71ed.js";import"./ScrollAndHighlight.beaaf011.js";import"./ScrollTo.81bea8a7.js";import"./params.af7ed354.js";import"./LicenseKeyBar.1e135846.js";import"./LogoGear.a6d9ae06.js";import"./AnimatedNumber.a0d95d3c.js";import"./numbers.9fc174f3.js";import"./Logo.99f25797.js";const C="all-in-one-seo-pack",x={components:{CoreAnimatedDannie:s,CoreCard:p,CoreHeader:m,GridContainer:_},data(){return{strings:{connecting:u("Connecting...",C)}}}},h={class:"animated-dannie"};function y(A,B,$,k,r,v){const e=n("core-header"),a=n("core-animated-dannie"),i=n("core-card"),c=n("grid-container");return f(),d("div",null,[o(e,{upgradeBar:!1,actions:!1}),o(c,null,{default:t(()=>[o(i,{"no-slide":"",toggles:!1,slug:"connect","header-text":r.strings.connecting},{default:t(()=>[g("div",h,[o(a,{mascot:"lab"})])]),_:1},8,["header-text"])]),_:1})])}const Y=l(x,[["render",y]]);export{Y as default};
